<?php
  /**
 * This file is part of a project maintained at  NC State University.
 *
 * More information is included in the project README.md.
 *
 * (c) NC State University
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace NCSU\Auth;

use NCSU\Auth\Exception\InvalidArgumentException;

/**
 * A class representing a normalize result of authentication from any
 * adapter.  All adapters must return an instance of this object from their
 * authenticate method.
 *
 * @author Dustin Wheeler <mdwheele@ncsu.edu>
 */
class AuthResult
{
    /**
     * The authenticate request was successful.
     */
    const SUCCESS = 0;
    /**
     * The authentication request failed for some reason.
     */
    const FAILURE = -1;

    /**
     * Authentication result code.
     *
     * @var int
     */
    protected $code;

    /**
     * A string representing the identity of the authenticated user.
     *
     * @var string
     */
    protected $identity;

    /**
     * An array of error messages if authentication is unsuccessful.
     *
     * @var array
     */
    protected $messages = array();

    /**
     * @param       $code
     * @param       $identity
     * @param array $messages
     *
     * @throws Exception\InvalidArgumentException
     */
    function __construct($code, $identity = '', array $messages = array())
    {
        if ($code === AuthResult::SUCCESS && empty($identity)) {
            throw new InvalidArgumentException('A successful authentication attempt must include an identity.');
        }

        if ($code === AuthResult::SUCCESS && count($messages) > 0) {
            throw new InvalidArgumentException('A successful authentication attempt should not include error messages.');
        }

        $this->code = (int) $code;
        $this->identity = $identity;
        $this->messages = $messages;
    }

    /**
     * Determines if the authentication attempt was valid or not.
     *
     * @return boolean returns true if valid, false otherwise.
     */
    public function isValid()
    {
        return $this->code === AuthResult::SUCCESS;
    }

    /**
     * Gets the authentication result code.
     *
     * @return int
     */
    public function getCode()
    {
        return $this->code;
    }

    /**
     * Returns the identity for the authentication attempt.
     *
     * @return mixed
     */
    public function getIdentity()
    {
        return $this->identity;
    }

    /**
     * Returns an array of error messages if the authentication attempt is not
     * successful.
     *
     * @return array
     */
    public function getMessages()
    {
        return $this->messages;
    }
} 